"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const classnames_1 = __importDefault(require("classnames"));
/**
 * add prefix to every `classnames` arguments
 * @param {string} CLS_PREFIX prefix
 * @param {string} seperator
 * @return {string} plain className
 */
const classPrefix = (CLS_PREFIX = '', seperator = '-') => {
    const addPrefix = (cls) => (!!CLS_PREFIX && !!cls ? `${CLS_PREFIX}${seperator}${cls}` : cls);
    const loop = (arg) => {
        if (typeof arg === 'string' || typeof arg === 'number') {
            return addPrefix(arg);
        }
        else if (Array.isArray(arg) && arg.length) {
            return arg.map(loop);
        }
        else if (arg != null && typeof arg === 'object') {
            const output = {};
            Object.entries(arg).forEach(([key, value]) => {
                output[addPrefix(key)] = value;
            });
            return output;
        }
        return arg;
    };
    return (...args) => {
        if (args.length === 0) {
            return CLS_PREFIX;
        }
        return classnames_1.default(...args.map(loop));
    };
};
exports.default = classPrefix;
